this.name					= "stealth_missionScript";
this.author					= "Thargoid";
this.copyright				= "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description			= "Mission script for Stealth OXP.";
this.version				= "1.05";

this.startUp = function()
	{
	// mission has already been rejected or completed, clean up and remove active script parts
	if(missionVariables.stealth_mission == "CASE_CLOSED") 
		{
		this.cleanUp();
		return;
		}
	 
	//initialise mission variables
	if(!missionVariables.stealth_mission) // mission general status
		{ missionVariables.stealth_mission = "OFFER"; }

	if(!missionVariables.stealth_barraCount) // how many barracuda's launched
		{ missionVariables.stealth_barraCount = 0; }
		
	if(!missionVariables.stealth_barraKills) // and how many killed by the player
		{ missionVariables.stealth_barraKills = 0; }
	}
	
this.cleanUp = function() // get rid of active script elements if no longer needed.
		{
		delete this.startUp;
		delete this.playerEnteredNewGalaxy;
		delete this.missionScreenOpportunity;
		delete this.choice;
		mission.setInstructionsKey(null);
		return;
		}

this.missionScreenOpportunity = function()
	{	
	// next check if we have any conditions preventing the offering or continuing of the mission
	if(!player.ship.docked // we're in space
			|| player.score < 512 // need to be dangerous rank to begin
			|| galaxyNumber != 2 // we're not in G3
			|| !player.ship.dockedStation.isMainStation // if we're not at the main station
			) 
		{ return; }
	
	if(system.ID === 131) // if we're at Lequena
		{
		if(player.ship.docked && player.ship.dockedStation.isMainStation && missionVariables.stealth_mission === "GO_GET_EM" && this.dockHint === "NO")
			{
			this.dockHint = "YES";
			mission.runScreen({title: "Anyone seen old Jeeq?", messageKey:"stealth_hint"});
			return;
			}
		}
	
	if(system.ID === 116) // if we're at Beenboer
		{
		switch(missionVariables.stealth_mission)
			{
			case "OFFER": // make the initial offer
				{
				mission.runScreen({title: "Catch the Barracuda", messageKey:"stealth_initialOffer", choicesKey:"stealth_choices"}, this.choice);
				break;
				}
			case "REJECTED": // player said no
				{
				missionVariables.stealth_mission = "CASE_CLOSED";
				mission.setInstructionsKey(null);
				mission.runScreen({title: "Ah well...", messageKey:"stealth_rejected"});
				break;
				}
			case "ACCEPTED": // player said yes
				{
				missionVariables.stealth_mission = "GO_GET_EM";
				mission.setInstructionsKey("stealth_missionShort");
				mission.markSystem(131);
				mission.runScreen({title: "Final briefing", messageKey:"stealth_accepted"});
				break;
				}
			case "BASE_DESTROYED": // mission over - base destroyed
				{
				missionVariables.stealth_mission = "CASE_CLOSED";
				mission.setInstructionsKey(null);
				mission.unmarkSystem(116);
				switch(missionVariables.stealth_barraKills)
					{
					case(6):
						{
						mission.runScreen({title: "Mission accomplished", messageKey:"stealth_allBarraDestroyed"});
						player.credits += 2000;
						break;
						}
					case(5):
					case(4):
					case(3):
						{
						missionVariables.stealth_award = missionVariables.stealth_barraKills * 250;
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_someBarraDestroyed"});
						player.credits += missionVariables.stealth_award;
						break;
						}
					case(2):
					case(1):
						{
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_fewBarraDestroyed"});
						break;
						}					
					case(0):
						{
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_noBarraDestroyed"});
						break;
						}
					}
				break;	
				}
			case "BASE_INTACT": // mission over - base intact
				{
				missionVariables.stealth_mission = "CASE_CLOSED";
				mission.setInstructionsKey(null);
				mission.unmarkSystem(116);
				switch(missionVariables.stealth_barraKills)
					{
					case(6):
						{
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_allBarraIntact"});
						player.credits += 1000;
						break;
						}
					case(5):
					case(4):
					case(3):
						{
						missionVariables.stealth_award = missionVariables.stealth_barraKills * 100;
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_someBarraIntact"});
						player.credits += missionVariables.stealth_award;
						break;
						}
					case(2):
					case(1):
						{
						mission.runScreen({title: "Mission debriefing", messageKey:"stealth_fewBarraIntact"});
						break;
						}					
					case(0):
						{
						mission.runScreen({title: "Mission failed", messageKey:"stealth_noBarraIntact"});
						break;
						}	
					}
				break;	
				}
			}
		return;	
		}
	}
	
this.choice = function(choice)
	{
	switch(choice)
		{
		case "STEALTH_1_ACCEPTED":
			{
			missionVariables.stealth_mission = "ACCEPTED";
			break;
			}
		case "STEALTH_2_REJECTED":
			{
			missionVariables.stealth_mission = "REJECTED";
			break;
			}
		}
	}

this.playerEnteredNewGalaxy	= function(galaxyNumber)
	{ // if we jump galaxies whilst mission is running or after rejection
	if(galaxyNumber == 3 && missionVariables.stealth_mission != "OFFER")
		{
		missionVariables.stealth_mission = "CASE_CLOSED";
		this.cleanUp();
		}
	}
	
this.shipWillExitWitchspace = function()
	{
	if(galaxyNumber == 2 && system.ID == 131 && missionVariables.stealth_mission && missionVariables.stealth_mission == "GO_GET_EM" && system.countShipsWithRole("stealth_base") == 0)
		{
		this.location = (Math.random() * 0.5) + 0.25;
		system.addShipsToRoute("stealth_base", 1, this.location, "ws");
		this.dockHint = "NO";
		}
	}
	
this.playerStartedJumpCountdown = function()
	{ 
	if(galaxyNumber == 2 && system.ID == 131 && missionVariables.stealth_mission && missionVariables.stealth_mission == "GO_GET_EM")
		{
		player.commsMessage("If we leave now there will not be sufficient time to return before the Barracuda base is evacuated - the mission will be lost!");
		delete this.playerStartedJumpCountdown;
		}
	}	
	
this.shipWillLaunchFromStation = function()
	{
	this.shipWillExitWitchspace();
	delete this.shipWillLaunchFromStation;
	}
